Documentation
¶
Overview ¶
Package meta provides the core client and utilities for interacting with the Meta Graph API.
Index ¶
Constants ¶
const ( // GraphAPIVersion defines the default API version used by [GraphAPIClient]. GraphAPIVersion = "v24.0" // GraphAPIBaseUrl defines the base URL for the Graph API used by [GraphAPIClient]. GraphAPIBaseUrl = "https://graph.facebook.com" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GraphAPIClient ¶
type GraphAPIClient struct {
HttpClient
ApiVersion string
BaseUrl string
AccessToken string
}
GraphAPIClient represents the main client structure for Meta Graph API requests. It embeds HttpClient to handle HTTP communications.
func (GraphAPIClient) Buffer ¶
func (c GraphAPIClient) Buffer(buf []byte) *bytes.Buffer
Buffer creates and returns a new bytes.Buffer from the provided byte slice.
type HttpClient ¶
type HttpClient = xhttp.HTTPClient
HttpClient is an alias for the external xhttp.HTTPClient.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package whatsapp provides a client and utilities for interacting with the WhatsApp Business API.
|
Package whatsapp provides a client and utilities for interacting with the WhatsApp Business API. |
|
group
Package group provides abstractions and functions to manage WhatsApp groups through the Meta API.
|
Package group provides abstractions and functions to manage WhatsApp groups through the Meta API. |
|
xjson
Package xjson provides utility functions and types for handling JSON data.
|
Package xjson provides utility functions and types for handling JSON data. |
Click to show internal directories.
Click to hide internal directories.